@@ -5,4 +5,4 @@ Created on Sat Jan 23 21:56:02 2021
 @author: Andro
 """
 
-from detvislib import *
\ No newline at end of file
+from DetVisLib import *
\ No newline at end of file
